#
# spec file for package xa
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xa
Version:        2.4.1
Release:        1.3
Summary:        High-speed, two-pass portable 6502 cross-assembler
License:        GPL-2.0-or-later
Group:          Development/Languages/Other
URL:            https://www.floodgap.com/retrotech/xa/
Source:         https://www.floodgap.com/retrotech/xa/dists/%{name}-%{version}.tar.gz
Patch0:         xa-fix-install.patch

%description
xa is a high-speed, two-pass portable cross-assembler for the 6502 CPU
with a C-like preprocessor. One of several popular 65xx assemblers, xa
is written in C and released under the GPL-2. It has been in continuous
development since 1989.

Other tools in the xa package are:
 * file65   - a tool for printing information about o65 object files.
 * ldo65    - a linker for o65 object files.
 * printcbm - a simple CBM BASIC detokenizer similar to the far more
              powerful petcat proviced by VICE.
 * reloc65  - a relocator for o65 object files.
 * uncpk    - a c64 cpk archive manager.

%prep
%autosetup -p1

%build
%make_build

%install
%make_install DESTDIR=%{buildroot}%{_prefix}

%check
make test

%files
%license COPYING
%doc ChangeLog
%{_bindir}/file65
%{_bindir}/ldo65
%{_bindir}/printcbm
%{_bindir}/reloc65
%{_bindir}/uncpk
%{_bindir}/xa
%{_mandir}/man1/file65.1%{?ext_man}
%{_mandir}/man1/ldo65.1%{?ext_man}
%{_mandir}/man1/printcbm.1%{?ext_man}
%{_mandir}/man1/reloc65.1%{?ext_man}
%{_mandir}/man1/uncpk.1%{?ext_man}
%{_mandir}/man1/xa.1%{?ext_man}

%changelog
* Sun Mar 24 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.4.1
  * Allow colon-based unnamed labels to be used separately of CA65 mode
    (such as with 65816) with -a. Implies -XMASM.
  * Restore ^ syntax for generating control sequences (e.g., "^m^j" evaluates as 0d 0a) with -k.
  * Fix a bug using cheap local labels in expressions.
  * Properly tag and match CPU types in o65 objects during relocation and linking.
  * Fix a bug with .align when aligning segments.
  * Better validation of arguments to indexed opcodes.
  * Testsuite expanded.
- Update to 2.4.0
  * Listing feature (-P, -F) in plain text or HTML, along with .listbytes to control
    how hex bytes get listed in the output.
  * Add -E commandline option to not stop after 20 errors, but show all of them.
  * Introduce -X compatibility set command line option to distinguish between MASM and CA65
    compatibility options; also adds C option for 0x and 0 to specify hex or octal.
    As a result, -M is now deprecated, and colons in comments may become the default
    in a future version.
  * Implement CA65 "cheap local labels", ":=" label definitions, and various pseudo-opcodes
    (.include, .import, .importzp, .zeropage, .proc (anonymous only), .endproc,
    .code, .org, .reloc).
  * -U option to allow all undefined labels in relocating mode; this allows exporting them
    to an .o65 file and link at a later time (or specify one at a time with -L).
  * Globals may also be specified manually with -g.
  * #error allows preprocessor-level assertions.
  * .assert allows assembler-level assertions.
  * Better fix for segfault with smaller arity macro issue.
  * Some 2.3.x features still allowed with -XXA23, which is obviously deprecated.
  * The quote escape character is now the \ (backslash), except if -XXA23.
  * Recursive /* */ comments are no longer allowed, except if -XXA23.
  * XA_MAJOR and XA_MINOR predefined macros, except if -XXA23.
  * -M is now deprecated (use -XMASM), just in case you forgot.
  * printcbm(1) is now deprecated (use VICE petcat, it does a lot more).
  * Previously deprecated options (16-bit mvn/mvp argument, -S, -x) finally removed.
    If you need this support, you must use 2.3.x.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Mon Feb 13 2023 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.3.14
